/*
 * Author: Richard Lord
 * Copyright (c) Richard Lord 2010
 * http://www.richardlord.net
 * 
 * Licence Agreement
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.richardlord.smartcomponents.twitter.managers
{
	import flash.events.Event;
	
	import mx.controls.Alert;
	
	import net.expantra.smartypants.Injector;
	import net.richardlord.smartcomponents.twitter.context.EventBus;
	import net.richardlord.smartcomponents.twitter.data.Tweet;
	import net.richardlord.smartcomponents.twitter.data.TweetCollection;
	import net.richardlord.smartcomponents.twitter.data.User;
	import net.richardlord.smartcomponents.twitter.events.AuthenticateEvent;
	import net.richardlord.smartcomponents.twitter.events.ServiceEvent;
	import net.richardlord.smartcomponents.twitter.events.TweetEvent;
	import net.richardlord.smartcomponents.twitter.events.VisibilityEvent;
	import net.richardlord.smartcomponents.twitter.services.TweetService;
	
	public class TweetManager
	{
		[Inject]
		public var service : TweetService;
		
		[Inject]
		public var user : User;
		
		[Inject]
		public var tweetCollection : TweetCollection;
		
		[Inject]
		public var eventBus : EventBus;
		
		[PostConstruct]
		public function setUpListeners( injector : Injector ) : void
		{
			service.addEventListener( TweetEvent.TWEET_LOADED, updateTweetCollection );
			service.addEventListener( ServiceEvent.REQUEST_FAILED, sendFailureAlert );
		}
		
		public function send( status : String ) : void
		{
			if ( !user.token )
			{
				eventBus.dispatchEvent( new AuthenticateEvent( AuthenticateEvent.SHOW_AUTHENTICATE ) );
			}
			else
			{
				service.send( status );
			}
		}
		
		private function updateTweetCollection( event:TweetEvent ) : void
		{
			tweetCollection.prependTweet( event.tweet );
			eventBus.dispatchEvent( new VisibilityEvent( VisibilityEvent.HIDE_CREATE_TWEET ) );
		}
		
		private function sendFailureAlert( event:Event = null ) : void
		{
			Alert.show( "Failed to send tweet" );
		}
	}
}