/*
 * Author: Richard Lord
 * Copyright (c) Richard Lord 2010
 * http://www.richardlord.net
 * 
 * Licence Agreement
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.richardlord.smartcomponents.twitter.services
{
	import flash.events.Event;
	import flash.events.EventDispatcher;
	import flash.net.URLRequestMethod;
	import flash.net.URLVariables;
	
	import net.expantra.smartypants.Injector;
	import net.richardlord.smartcomponents.twitter.data.TweetCollection;
	import net.richardlord.smartcomponents.twitter.events.ServiceEvent;
	import net.richardlord.smartcomponents.twitter.events.TweetCollectionEvent;
	import net.richardlord.smartcomponents.twitter.services.parsers.TimelineAtomParser;
	import net.richardlord.smartcomponents.twitter.services.tools.TwitterRequest;
	
	public class HomeService extends EventDispatcher
	{
		private static const SERVICE_URL : String = "http://api.twitter.com/1/statuses/home_timeline.atom";
		
		[Inject]
		public var request : TwitterRequest;
		
		[Inject]
		public var parser : TimelineAtomParser;
		
		[PostConstruct]
		public function setUpListeners( injector : Injector ) : void
		{
			request.addEventListener( ServiceEvent.REQUEST_COMPLETE, parseResults );
			request.addEventListener( ServiceEvent.REQUEST_FAILED, signalFailure );
		}
		
		public function send( resultsCount : uint ) : void
		{
			request.loadDataFormat = TwitterRequest.FORMAT_XML;
			request.sendMethod = URLRequestMethod.GET;
			request.url = SERVICE_URL;
			
			var data : URLVariables = new URLVariables();
			data.count = resultsCount;
			data.page = 1;
			request.sendData = data;
			
			request.sendAndLoad();
		}
		
		private function parseResults( event:ServiceEvent ) : void
		{
			var tweets : TweetCollection = parser.parseFeed( event.data as XML );
			dispatchEvent( new TweetCollectionEvent( TweetCollectionEvent.TWEETS_LOADED, tweets ) );
		}
		
		private function signalFailure( event:Event = null ) : void
		{
			dispatchEvent( new ServiceEvent( ServiceEvent.REQUEST_FAILED ) );
		}
	}
}